@@ -6,9 +6,9 @@ class Venue(models.Model):
     venue_name = models.TextField(max_length=80, primary_key=True)
     venue_path = models.TextField(max_length=255)
 
-    """def __init__(self):
+    def __init__(self):
         self.venue_root = os.path.abspath(os.path.join(self.venue_path, self.venue_name))
-
+    """
         if not os.path.exists(self.venue_root):
             print 'venue does not exist at %s' % self.venue_root
             self = None
